All of lore.kernel.org
 help / color / mirror / Atom feed
* [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts
@ 2020-12-04 11:51 Janusz Krzysztofik
  2020-12-04 11:57 ` [Intel-gfx] " Janusz Krzysztofik
                   ` (3 more replies)
  0 siblings, 4 replies; 10+ messages in thread
From: Janusz Krzysztofik @ 2020-12-04 11:51 UTC (permalink / raw)
  To: igt-dev; +Cc: drm-intel, Petri Latvala

We may still be interested in results of a test even if it has tainted
the kernel.  On the other hand, we need to kill the test on taint if no
other means of killing it on a jam is active.

If abort on both kernel taint or a timeout is requested, decrease all
potential timeouts significantly while the taint is detected instead of
aborting immediately.  However, report the taint as the reason of the
abort if a timeout decreased by the taint expires.

Signed-off-by: Janusz Krzysztofik <janusz.krzysztofik@linux.intel.com>
---
 runner/executor.c | 30 ++++++++++++++++++++++--------
 1 file changed, 22 insertions(+), 8 deletions(-)

diff --git a/runner/executor.c b/runner/executor.c
index 1688ae41d..e39d8a73b 100644
--- a/runner/executor.c
+++ b/runner/executor.c
@@ -726,6 +726,8 @@ static const char *need_to_timeout(struct settings *settings,
 				   double time_since_kill,
 				   size_t disk_usage)
 {
+	int decrease = 1;
+
 	if (killed) {
 		/*
 		 * Timeout after being killed is a hardcoded amount
@@ -753,20 +755,32 @@ static const char *need_to_timeout(struct settings *settings,
 	}
 
 	/*
 	 * If we're configured to care about taints, kill the
 	 * test if there's a taint.
 	 */
 	if (settings->abort_mask & ABORT_TAINT &&
-	    is_tainted(taints))
-		return "Killing the test because the kernel is tainted.\n";
+	    is_tainted(taints)) {
+		/* list of timeouts that may postpone immediate kill on taint */
+		if (settings->per_test_timeout || settings->inactivity_timeout)
+			decrease = 10;
+		else
+			return "Killing the test because the kernel is tainted.\n";
+	}
 
 	if (settings->per_test_timeout != 0 &&
-	    time_since_subtest > settings->per_test_timeout)
-		return show_kernel_task_state("Per-test timeout exceeded. Killing the current test with SIGQUIT.\n");
+	    time_since_subtest > settings->per_test_timeout / decrease) {
+		if (decrease > 1)
+			return "Killing the test because the kernel is tainted.\n";
+		return "Per-test timeout exceeded. Killing the current test with SIGQUIT.\n";
+	}
 
 	if (settings->inactivity_timeout != 0 &&
-	    time_since_activity > settings->inactivity_timeout)
-		return show_kernel_task_state("Inactivity timeout exceeded. Killing the current test with SIGQUIT.\n");
+	    time_since_activity > settings->inactivity_timeout / decrease ) {
+		if (decrease > 1)
+			return "Killing the test because the kernel is tainted.\n";
+		return "Inactivity timeout exceeded. Killing the current test with SIGQUIT.\n";
+	}
 
 	if (disk_usage_limit_exceeded(settings, disk_usage))
 		return "Disk usage limit exceeded.\n";
@@ -753,20 +755,32 @@ static const char *need_to_timeout(struct settings *settings,
 
 	/*
-	 * If we're configured to care about taints, kill the
-	 * test if there's a taint.
+	 * If we're configured to care about taints,
+	 * decrease timeouts in use if there's a taint,
+	 * or kill the test if no timeouts have been requested.
 	 */
 	if (settings->abort_mask & ABORT_TAINT &&
-- 
2.21.1

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply related	[flat|nested] 10+ messages in thread

* Re: [Intel-gfx] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts
  2020-12-04 11:51 [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts Janusz Krzysztofik
@ 2020-12-04 11:57 ` Janusz Krzysztofik
  2020-12-04 12:06 ` [igt-dev] " Chris Wilson
                   ` (2 subsequent siblings)
  3 siblings, 0 replies; 10+ messages in thread
From: Janusz Krzysztofik @ 2020-12-04 11:57 UTC (permalink / raw)
  To: igt-dev; +Cc: intel-gfx

Submitted with incorrect address of i915 list out of top of my head in
Cc:, sorry.

Janusz
 

On Fri, 2020-12-04 at 12:51 +0100, Janusz Krzysztofik wrote:
> We may still be interested in results of a test even if it has tainted
> the kernel.  On the other hand, we need to kill the test on taint if no
> other means of killing it on a jam is active.
> 
> If abort on both kernel taint or a timeout is requested, decrease all
> potential timeouts significantly while the taint is detected instead of
> aborting immediately.  However, report the taint as the reason of the
> abort if a timeout decreased by the taint expires.
> 
> Signed-off-by: Janusz Krzysztofik <janusz.krzysztofik@linux.intel.com>
> ---
>  runner/executor.c | 30 ++++++++++++++++++++++--------
>  1 file changed, 22 insertions(+), 8 deletions(-)
> 
> diff --git a/runner/executor.c b/runner/executor.c
> index 1688ae41d..e39d8a73b 100644
> --- a/runner/executor.c
> +++ b/runner/executor.c
> @@ -726,6 +726,8 @@ static const char *need_to_timeout(struct settings *settings,
>  				   double time_since_kill,
>  				   size_t disk_usage)
>  {
> +	int decrease = 1;
> +
>  	if (killed) {
>  		/*
>  		 * Timeout after being killed is a hardcoded amount
> @@ -753,20 +755,32 @@ static const char *need_to_timeout(struct settings *settings,
>  	}
>  
>  	/*
> -	 * If we're configured to care about taints, kill the
> -	 * test if there's a taint.
> +	 * If we're configured to care about taints,
> +	 * decrease timeouts in use if there's a taint,
> +	 * or kill the test if no timeouts have been requested.
>  	 */
>  	if (settings->abort_mask & ABORT_TAINT &&
> -	    is_tainted(taints))
> -		return "Killing the test because the kernel is tainted.\n";
> +	    is_tainted(taints)) {
> +		/* list of timeouts that may postpone immediate kill on taint */
> +		if (settings->per_test_timeout || settings->inactivity_timeout)
> +			decrease = 10;
> +		else
> +			return "Killing the test because the kernel is tainted.\n";
> +	}
>  
>  	if (settings->per_test_timeout != 0 &&
> -	    time_since_subtest > settings->per_test_timeout)
> -		return show_kernel_task_state("Per-test timeout exceeded. Killing the current test with SIGQUIT.\n");
> +	    time_since_subtest > settings->per_test_timeout / decrease) {
> +		if (decrease > 1)
> +			return "Killing the test because the kernel is tainted.\n";
> +		return "Per-test timeout exceeded. Killing the current test with SIGQUIT.\n";
> +	}
>  
>  	if (settings->inactivity_timeout != 0 &&
> -	    time_since_activity > settings->inactivity_timeout)
> -		return show_kernel_task_state("Inactivity timeout exceeded. Killing the current test with SIGQUIT.\n");
> +	    time_since_activity > settings->inactivity_timeout / decrease ) {
> +		if (decrease > 1)
> +			return "Killing the test because the kernel is tainted.\n";
> +		return "Inactivity timeout exceeded. Killing the current test with SIGQUIT.\n";
> +	}
>  
>  	if (disk_usage_limit_exceeded(settings, disk_usage))
>  		return "Disk usage limit exceeded.\n";

_______________________________________________
Intel-gfx mailing list
Intel-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/intel-gfx

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts
  2020-12-04 11:51 [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts Janusz Krzysztofik
  2020-12-04 11:57 ` [Intel-gfx] " Janusz Krzysztofik
@ 2020-12-04 12:06 ` Chris Wilson
  2020-12-04 12:20     ` Janusz Krzysztofik
  2020-12-04 12:39 ` [igt-dev] ✓ Fi.CI.BAT: success for " Patchwork
  2020-12-04 14:35 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork
  3 siblings, 1 reply; 10+ messages in thread
From: Chris Wilson @ 2020-12-04 12:06 UTC (permalink / raw)
  To: Janusz Krzysztofik, igt-dev; +Cc: drm-intel, Petri Latvala

Quoting Janusz Krzysztofik (2020-12-04 11:51:38)
> We may still be interested in results of a test even if it has tainted
> the kernel.  On the other hand, we need to kill the test on taint if no
> other means of killing it on a jam is active.

Just so long as we are confident that the original error is preserved,
and not lost under a deluge of what may come next. E.g. is there
sufficient syncs after detecting the taint to record the kernel logs
asap?

Although that the kernel taints is a strong indicator the test results
are unreliable (or even irrelevant), imo.
-Chris
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [Intel-gfx] [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts
  2020-12-04 12:06 ` [igt-dev] " Chris Wilson
@ 2020-12-04 12:20     ` Janusz Krzysztofik
  0 siblings, 0 replies; 10+ messages in thread
From: Janusz Krzysztofik @ 2020-12-04 12:20 UTC (permalink / raw)
  To: Chris Wilson, igt-dev; +Cc: intel-gfx

On Fri, 2020-12-04 at 12:06 +0000, Chris Wilson wrote:
> Quoting Janusz Krzysztofik (2020-12-04 11:51:38)
> > We may still be interested in results of a test even if it has tainted
> > the kernel.  On the other hand, we need to kill the test on taint if no
> > other means of killing it on a jam is active.
> 
> Just so long as we are confident that the original error is preserved,
> and not lost under a deluge of what may come next. E.g. is there
> sufficient syncs after detecting the taint to record the kernel logs
> asap?
> 
> Although that the kernel taints is a strong indicator the test results
> are unreliable (or even irrelevant), imo.

Unless tainted with kernel warnings which result from bugs that can be
fixed, I believe.

Thanks,
Janusz

> -Chris

_______________________________________________
Intel-gfx mailing list
Intel-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/intel-gfx

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts
@ 2020-12-04 12:20     ` Janusz Krzysztofik
  0 siblings, 0 replies; 10+ messages in thread
From: Janusz Krzysztofik @ 2020-12-04 12:20 UTC (permalink / raw)
  To: Chris Wilson, igt-dev; +Cc: intel-gfx, Petri Latvala

On Fri, 2020-12-04 at 12:06 +0000, Chris Wilson wrote:
> Quoting Janusz Krzysztofik (2020-12-04 11:51:38)
> > We may still be interested in results of a test even if it has tainted
> > the kernel.  On the other hand, we need to kill the test on taint if no
> > other means of killing it on a jam is active.
> 
> Just so long as we are confident that the original error is preserved,
> and not lost under a deluge of what may come next. E.g. is there
> sufficient syncs after detecting the taint to record the kernel logs
> asap?
> 
> Although that the kernel taints is a strong indicator the test results
> are unreliable (or even irrelevant), imo.

Unless tainted with kernel warnings which result from bugs that can be
fixed, I believe.

Thanks,
Janusz

> -Chris

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 10+ messages in thread

* [igt-dev] ✓ Fi.CI.BAT: success for runner: Don't kill a test on taint if watching timeouts
  2020-12-04 11:51 [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts Janusz Krzysztofik
  2020-12-04 11:57 ` [Intel-gfx] " Janusz Krzysztofik
  2020-12-04 12:06 ` [igt-dev] " Chris Wilson
@ 2020-12-04 12:39 ` Patchwork
  2020-12-04 14:35 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork
  3 siblings, 0 replies; 10+ messages in thread
From: Patchwork @ 2020-12-04 12:39 UTC (permalink / raw)
  To: Janusz Krzysztofik; +Cc: igt-dev


[-- Attachment #1.1: Type: text/plain, Size: 2006 bytes --]

== Series Details ==

Series: runner: Don't kill a test on taint if watching timeouts
URL   : https://patchwork.freedesktop.org/series/84577/
State : success

== Summary ==

CI Bug Log - changes from CI_DRM_9441 -> IGTPW_5249
====================================================

Summary
-------

  **SUCCESS**

  No regressions found.

  External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html

Known issues
------------

  Here are the changes found in IGTPW_5249 that come from known issues:

### IGT changes ###

#### Issues hit ####

  * igt@i915_selftest@live@blt:
    - fi-hsw-4770:        [PASS][1] -> [DMESG-FAIL][2] ([i915#1409])
   [1]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/fi-hsw-4770/igt@i915_selftest@live@blt.html
   [2]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/fi-hsw-4770/igt@i915_selftest@live@blt.html

  
#### Possible fixes ####

  * igt@gem_exec_gttfill@basic:
    - fi-kbl-8809g:       [INCOMPLETE][3] ([i915#2405]) -> [PASS][4]
   [3]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/fi-kbl-8809g/igt@gem_exec_gttfill@basic.html
   [4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/fi-kbl-8809g/igt@gem_exec_gttfill@basic.html

  
  [i915#1409]: https://gitlab.freedesktop.org/drm/intel/issues/1409
  [i915#2405]: https://gitlab.freedesktop.org/drm/intel/issues/2405


Participating hosts (43 -> 37)
------------------------------

  Missing    (6): fi-ilk-m540 fi-hsw-4200u fi-bsw-cyan fi-dg1-1 fi-tgl-y fi-bdw-samus 


Build changes
-------------

  * CI: CI-20190529 -> None
  * IGT: IGT_5880 -> IGTPW_5249

  CI-20190529: 20190529
  CI_DRM_9441: 6e992bb7585d1bee238776d8fe0512a70a22a1a0 @ git://anongit.freedesktop.org/gfx-ci/linux
  IGTPW_5249: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
  IGT_5880: d67bad61dc9a7515f94a7eecadd3bcd6b4f9d49e @ git://anongit.freedesktop.org/xorg/app/intel-gpu-tools

== Logs ==

For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html

[-- Attachment #1.2: Type: text/html, Size: 2620 bytes --]

[-- Attachment #2: Type: text/plain, Size: 154 bytes --]

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 10+ messages in thread

* [igt-dev] ✗ Fi.CI.IGT: failure for runner: Don't kill a test on taint if watching timeouts
  2020-12-04 11:51 [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts Janusz Krzysztofik
                   ` (2 preceding siblings ...)
  2020-12-04 12:39 ` [igt-dev] ✓ Fi.CI.BAT: success for " Patchwork
@ 2020-12-04 14:35 ` Patchwork
  2020-12-04 15:44   ` Janusz Krzysztofik
  2020-12-04 17:28   ` [igt-dev] ✗ " Janusz Krzysztofik
  3 siblings, 2 replies; 10+ messages in thread
From: Patchwork @ 2020-12-04 14:35 UTC (permalink / raw)
  To: Janusz Krzysztofik; +Cc: igt-dev


[-- Attachment #1.1: Type: text/plain, Size: 21866 bytes --]

== Series Details ==

Series: runner: Don't kill a test on taint if watching timeouts
URL   : https://patchwork.freedesktop.org/series/84577/
State : failure

== Summary ==

CI Bug Log - changes from CI_DRM_9441_full -> IGTPW_5249_full
====================================================

Summary
-------

  **FAILURE**

  Serious unknown changes coming with IGTPW_5249_full absolutely need to be
  verified manually.
  
  If you think the reported changes have nothing to do with the changes
  introduced in IGTPW_5249_full, please notify your bug team to allow them
  to document this new failure mode, which will reduce false positives in CI.

  External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html

Possible new issues
-------------------

  Here are the unknown changes that may have been introduced in IGTPW_5249_full:

### IGT changes ###

#### Possible regressions ####

  * igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend:
    - shard-iclb:         [PASS][1] -> [DMESG-WARN][2]
   [1]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb2/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
   [2]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb6/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html

  
#### Warnings ####

  * igt@gem_exec_reloc@basic-parallel:
    - shard-kbl:          [TIMEOUT][3] ([i915#1729]) -> [TIMEOUT][4]
   [3]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl2/igt@gem_exec_reloc@basic-parallel.html
   [4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl4/igt@gem_exec_reloc@basic-parallel.html
    - shard-tglb:         [TIMEOUT][5] ([i915#1729]) -> [TIMEOUT][6]
   [5]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb7/igt@gem_exec_reloc@basic-parallel.html
   [6]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb1/igt@gem_exec_reloc@basic-parallel.html
    - shard-apl:          [TIMEOUT][7] ([i915#1729]) -> [TIMEOUT][8]
   [7]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-apl4/igt@gem_exec_reloc@basic-parallel.html
   [8]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-apl4/igt@gem_exec_reloc@basic-parallel.html
    - shard-iclb:         [TIMEOUT][9] ([i915#1729]) -> [TIMEOUT][10]
   [9]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb7/igt@gem_exec_reloc@basic-parallel.html
   [10]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb5/igt@gem_exec_reloc@basic-parallel.html
    - shard-glk:          [TIMEOUT][11] ([i915#1729]) -> [TIMEOUT][12]
   [11]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-glk5/igt@gem_exec_reloc@basic-parallel.html
   [12]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk5/igt@gem_exec_reloc@basic-parallel.html

  
Known issues
------------

  Here are the changes found in IGTPW_5249_full that come from known issues:

### IGT changes ###

#### Issues hit ####

  * igt@i915_pm_backlight@fade_with_suspend:
    - shard-tglb:         [PASS][13] -> [DMESG-WARN][14] ([i915#1436] / [i915#1602] / [i915#1887] / [i915#2411])
   [13]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb1/igt@i915_pm_backlight@fade_with_suspend.html
   [14]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb1/igt@i915_pm_backlight@fade_with_suspend.html
    - shard-iclb:         [PASS][15] -> [DMESG-WARN][16] ([i915#1602])
   [15]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb8/igt@i915_pm_backlight@fade_with_suspend.html
   [16]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb2/igt@i915_pm_backlight@fade_with_suspend.html

  * igt@i915_pm_rpm@dpms-non-lpsp:
    - shard-kbl:          [PASS][17] -> [SKIP][18] ([fdo#109271])
   [17]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl4/igt@i915_pm_rpm@dpms-non-lpsp.html
   [18]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl2/igt@i915_pm_rpm@dpms-non-lpsp.html
    - shard-apl:          [PASS][19] -> [SKIP][20] ([fdo#109271])
   [19]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-apl7/igt@i915_pm_rpm@dpms-non-lpsp.html
   [20]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-apl2/igt@i915_pm_rpm@dpms-non-lpsp.html
    - shard-glk:          [PASS][21] -> [SKIP][22] ([fdo#109271])
   [21]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-glk3/igt@i915_pm_rpm@dpms-non-lpsp.html
   [22]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk2/igt@i915_pm_rpm@dpms-non-lpsp.html
    - shard-hsw:          [PASS][23] -> [SKIP][24] ([fdo#109271])
   [23]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-hsw2/igt@i915_pm_rpm@dpms-non-lpsp.html
   [24]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-hsw7/igt@i915_pm_rpm@dpms-non-lpsp.html

  * igt@i915_suspend@forcewake:
    - shard-kbl:          [PASS][25] -> [DMESG-WARN][26] ([i915#180])
   [25]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl4/igt@i915_suspend@forcewake.html
   [26]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl2/igt@i915_suspend@forcewake.html

  * igt@kms_async_flips@test-time-stamp:
    - shard-tglb:         [PASS][27] -> [FAIL][28] ([i915#2597])
   [27]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb1/igt@kms_async_flips@test-time-stamp.html
   [28]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb2/igt@kms_async_flips@test-time-stamp.html

  * igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding:
    - shard-kbl:          [PASS][29] -> [FAIL][30] ([i915#54])
   [29]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl4/igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding.html
   [30]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl1/igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding.html
    - shard-glk:          [PASS][31] -> [FAIL][32] ([i915#54])
   [31]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-glk3/igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding.html
   [32]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk3/igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding.html
    - shard-apl:          [PASS][33] -> [FAIL][34] ([i915#54])
   [33]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-apl3/igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding.html
   [34]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-apl8/igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding.html

  * igt@kms_draw_crc@fill-fb:
    - shard-snb:          [PASS][35] -> [SKIP][36] ([fdo#109271]) +2 similar issues
   [35]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-snb2/igt@kms_draw_crc@fill-fb.html
   [36]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-snb2/igt@kms_draw_crc@fill-fb.html

  * igt@kms_psr@psr2_cursor_plane_move:
    - shard-iclb:         [PASS][37] -> [SKIP][38] ([fdo#109441]) +2 similar issues
   [37]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb2/igt@kms_psr@psr2_cursor_plane_move.html
   [38]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb4/igt@kms_psr@psr2_cursor_plane_move.html

  * igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend:
    - shard-hsw:          [PASS][39] -> [DMESG-WARN][40] ([i915#2637])
   [39]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-hsw1/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
   [40]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-hsw7/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
    - shard-kbl:          [PASS][41] -> [INCOMPLETE][42] ([i915#155])
   [41]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl7/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
   [42]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl2/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
    - shard-apl:          [PASS][43] -> [DMESG-WARN][44] ([i915#2635])
   [43]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-apl1/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
   [44]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-apl2/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
    - shard-glk:          [PASS][45] -> [DMESG-WARN][46] ([i915#2635])
   [45]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-glk4/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
   [46]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk2/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
    - shard-tglb:         [PASS][47] -> [INCOMPLETE][48] ([i915#1436] / [i915#1602] / [i915#1798] / [i915#1887] / [i915#1982] / [i915#2411] / [i915#456])
   [47]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb8/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html
   [48]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb2/igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend.html

  
#### Possible fixes ####

  * igt@gem_exec_gttfill@engines@rcs0:
    - shard-glk:          [DMESG-WARN][49] ([i915#118] / [i915#95]) -> [PASS][50] +2 similar issues
   [49]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-glk7/igt@gem_exec_gttfill@engines@rcs0.html
   [50]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk1/igt@gem_exec_gttfill@engines@rcs0.html

  * igt@i915_pm_rpm@sysfs-read:
    - shard-iclb:         [SKIP][51] ([i915#579]) -> [PASS][52]
   [51]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb3/igt@i915_pm_rpm@sysfs-read.html
   [52]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb7/igt@i915_pm_rpm@sysfs-read.html
    - shard-tglb:         [SKIP][53] ([i915#579]) -> [PASS][54]
   [53]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb2/igt@i915_pm_rpm@sysfs-read.html
   [54]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb5/igt@i915_pm_rpm@sysfs-read.html

  * igt@kms_color@pipe-a-ctm-max:
    - shard-kbl:          [FAIL][55] ([i915#1292]) -> [PASS][56]
   [55]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl3/igt@kms_color@pipe-a-ctm-max.html
   [56]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl1/igt@kms_color@pipe-a-ctm-max.html
    - shard-apl:          [FAIL][57] ([i915#1292]) -> [PASS][58]
   [57]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-apl6/igt@kms_color@pipe-a-ctm-max.html
   [58]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-apl8/igt@kms_color@pipe-a-ctm-max.html

  * igt@kms_cursor_legacy@2x-long-flip-vs-cursor-legacy:
    - shard-glk:          [FAIL][59] ([i915#72]) -> [PASS][60]
   [59]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-glk1/igt@kms_cursor_legacy@2x-long-flip-vs-cursor-legacy.html
   [60]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk6/igt@kms_cursor_legacy@2x-long-flip-vs-cursor-legacy.html

  * igt@kms_cursor_legacy@cursor-vs-flip-toggle:
    - shard-hsw:          [FAIL][61] ([i915#2370]) -> [PASS][62]
   [61]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-hsw1/igt@kms_cursor_legacy@cursor-vs-flip-toggle.html
   [62]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-hsw7/igt@kms_cursor_legacy@cursor-vs-flip-toggle.html

  * igt@kms_fbcon_fbt@fbc-suspend:
    - shard-kbl:          [INCOMPLETE][63] ([i915#155] / [i915#180]) -> [PASS][64]
   [63]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl2/igt@kms_fbcon_fbt@fbc-suspend.html
   [64]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl2/igt@kms_fbcon_fbt@fbc-suspend.html

  * igt@kms_psr@psr2_no_drrs:
    - shard-iclb:         [SKIP][65] ([fdo#109441]) -> [PASS][66] +1 similar issue
   [65]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb7/igt@kms_psr@psr2_no_drrs.html
   [66]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb2/igt@kms_psr@psr2_no_drrs.html

  * igt@perf_pmu@rc6-runtime-pm:
    - shard-glk:          [SKIP][67] ([fdo#109271]) -> [PASS][68] +1 similar issue
   [67]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-glk1/igt@perf_pmu@rc6-runtime-pm.html
   [68]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk3/igt@perf_pmu@rc6-runtime-pm.html
    - shard-apl:          [SKIP][69] ([fdo#109271]) -> [PASS][70] +1 similar issue
   [69]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-apl2/igt@perf_pmu@rc6-runtime-pm.html
   [70]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-apl8/igt@perf_pmu@rc6-runtime-pm.html
    - shard-kbl:          [SKIP][71] ([fdo#109271]) -> [PASS][72] +1 similar issue
   [71]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl6/igt@perf_pmu@rc6-runtime-pm.html
   [72]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl3/igt@perf_pmu@rc6-runtime-pm.html
    - shard-tglb:         [SKIP][73] ([fdo#111719]) -> [PASS][74]
   [73]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb6/igt@perf_pmu@rc6-runtime-pm.html
   [74]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb3/igt@perf_pmu@rc6-runtime-pm.html
    - shard-hsw:          [SKIP][75] ([fdo#109271]) -> [PASS][76] +1 similar issue
   [75]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-hsw6/igt@perf_pmu@rc6-runtime-pm.html
   [76]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-hsw2/igt@perf_pmu@rc6-runtime-pm.html
    - shard-iclb:         [SKIP][77] ([i915#293]) -> [PASS][78]
   [77]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb1/igt@perf_pmu@rc6-runtime-pm.html
   [78]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb4/igt@perf_pmu@rc6-runtime-pm.html

  
#### Warnings ####

  * igt@i915_pm_rc6_residency@rc6-fence:
    - shard-iclb:         [WARN][79] ([i915#1804] / [i915#2684]) -> [WARN][80] ([i915#2681] / [i915#2684])
   [79]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb7/igt@i915_pm_rc6_residency@rc6-fence.html
   [80]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb8/igt@i915_pm_rc6_residency@rc6-fence.html

  * igt@i915_pm_rc6_residency@rc6-idle:
    - shard-iclb:         [WARN][81] ([i915#2684]) -> [WARN][82] ([i915#2681] / [i915#2684])
   [81]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb2/igt@i915_pm_rc6_residency@rc6-idle.html
   [82]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb1/igt@i915_pm_rc6_residency@rc6-idle.html

  * igt@i915_pm_rpm@dpms-non-lpsp:
    - shard-tglb:         [SKIP][83] ([fdo#111644] / [i915#1397] / [i915#2411]) -> [SKIP][84] ([i915#579])
   [83]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb3/igt@i915_pm_rpm@dpms-non-lpsp.html
   [84]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb2/igt@i915_pm_rpm@dpms-non-lpsp.html
    - shard-iclb:         [SKIP][85] ([fdo#110892]) -> [SKIP][86] ([i915#579])
   [85]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb8/igt@i915_pm_rpm@dpms-non-lpsp.html
   [86]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb6/igt@i915_pm_rpm@dpms-non-lpsp.html

  * igt@i915_pm_rpm@modeset-pc8-residency-stress:
    - shard-tglb:         [SKIP][87] ([i915#579]) -> [SKIP][88] ([fdo#109506] / [i915#2411])
   [87]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb6/igt@i915_pm_rpm@modeset-pc8-residency-stress.html
   [88]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb7/igt@i915_pm_rpm@modeset-pc8-residency-stress.html
    - shard-iclb:         [SKIP][89] ([i915#579]) -> [SKIP][90] ([fdo#109293] / [fdo#109506])
   [89]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb1/igt@i915_pm_rpm@modeset-pc8-residency-stress.html
   [90]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb4/igt@i915_pm_rpm@modeset-pc8-residency-stress.html

  * igt@runner@aborted:
    - shard-kbl:          ([FAIL][91], [FAIL][92]) ([i915#2295] / [i915#2722] / [i915#483] / [i915#92]) -> ([FAIL][93], [FAIL][94], [FAIL][95]) ([i915#1814] / [i915#2295] / [i915#2722] / [i915#483] / [i915#602])
   [91]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl6/igt@runner@aborted.html
   [92]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-kbl2/igt@runner@aborted.html
   [93]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl2/igt@runner@aborted.html
   [94]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl4/igt@runner@aborted.html
   [95]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-kbl2/igt@runner@aborted.html
    - shard-iclb:         [FAIL][96] ([i915#2295] / [i915#2722] / [i915#483]) -> ([FAIL][97], [FAIL][98], [FAIL][99]) ([i915#1814] / [i915#2295] / [i915#2722] / [i915#483])
   [96]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-iclb6/igt@runner@aborted.html
   [97]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb2/igt@runner@aborted.html
   [98]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb1/igt@runner@aborted.html
   [99]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-iclb6/igt@runner@aborted.html
    - shard-apl:          [FAIL][100] ([i915#2295] / [i915#2722]) -> ([FAIL][101], [FAIL][102]) ([i915#1814] / [i915#2295] / [i915#2722])
   [100]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-apl3/igt@runner@aborted.html
   [101]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-apl2/igt@runner@aborted.html
   [102]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-apl7/igt@runner@aborted.html
    - shard-glk:          [FAIL][103] ([i915#2295] / [i915#2722] / [k.org#202321]) -> ([FAIL][104], [FAIL][105]) ([i915#1814] / [i915#2295] / [i915#2722] / [k.org#202321])
   [103]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-glk1/igt@runner@aborted.html
   [104]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk2/igt@runner@aborted.html
   [105]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-glk4/igt@runner@aborted.html
    - shard-tglb:         [FAIL][106] ([i915#2295] / [i915#2722]) -> ([FAIL][107], [FAIL][108], [FAIL][109]) ([i915#1602] / [i915#2295] / [i915#2722])
   [106]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_9441/shard-tglb7/igt@runner@aborted.html
   [107]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb1/igt@runner@aborted.html
   [108]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb6/igt@runner@aborted.html
   [109]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/shard-tglb2/igt@runner@aborted.html

  
  [fdo#109271]: https://bugs.freedesktop.org/show_bug.cgi?id=109271
  [fdo#109293]: https://bugs.freedesktop.org/show_bug.cgi?id=109293
  [fdo#109441]: https://bugs.freedesktop.org/show_bug.cgi?id=109441
  [fdo#109506]: https://bugs.freedesktop.org/show_bug.cgi?id=109506
  [fdo#110892]: https://bugs.freedesktop.org/show_bug.cgi?id=110892
  [fdo#111644]: https://bugs.freedesktop.org/show_bug.cgi?id=111644
  [fdo#111719]: https://bugs.freedesktop.org/show_bug.cgi?id=111719
  [i915#118]: https://gitlab.freedesktop.org/drm/intel/issues/118
  [i915#1292]: https://gitlab.freedesktop.org/drm/intel/issues/1292
  [i915#1397]: https://gitlab.freedesktop.org/drm/intel/issues/1397
  [i915#1436]: https://gitlab.freedesktop.org/drm/intel/issues/1436
  [i915#155]: https://gitlab.freedesktop.org/drm/intel/issues/155
  [i915#1602]: https://gitlab.freedesktop.org/drm/intel/issues/1602
  [i915#1729]: https://gitlab.freedesktop.org/drm/intel/issues/1729
  [i915#1798]: https://gitlab.freedesktop.org/drm/intel/issues/1798
  [i915#180]: https://gitlab.freedesktop.org/drm/intel/issues/180
  [i915#1804]: https://gitlab.freedesktop.org/drm/intel/issues/1804
  [i915#1814]: https://gitlab.freedesktop.org/drm/intel/issues/1814
  [i915#1887]: https://gitlab.freedesktop.org/drm/intel/issues/1887
  [i915#1982]: https://gitlab.freedesktop.org/drm/intel/issues/1982
  [i915#2295]: https://gitlab.freedesktop.org/drm/intel/issues/2295
  [i915#2370]: https://gitlab.freedesktop.org/drm/intel/issues/2370
  [i915#2411]: https://gitlab.freedesktop.org/drm/intel/issues/2411
  [i915#2597]: https://gitlab.freedesktop.org/drm/intel/issues/2597
  [i915#2635]: https://gitlab.freedesktop.org/drm/intel/issues/2635
  [i915#2637]: https://gitlab.freedesktop.org/drm/intel/issues/2637
  [i915#2681]: https://gitlab.freedesktop.org/drm/intel/issues/2681
  [i915#2684]: https://gitlab.freedesktop.org/drm/intel/issues/2684
  [i915#2722]: https://gitlab.freedesktop.org/drm/intel/issues/2722
  [i915#293]: https://gitlab.freedesktop.org/drm/intel/issues/293
  [i915#456]: https://gitlab.freedesktop.org/drm/intel/issues/456
  [i915#483]: https://gitlab.freedesktop.org/drm/intel/issues/483
  [i915#54]: https://gitlab.freedesktop.org/drm/intel/issues/54
  [i915#579]: https://gitlab.freedesktop.org/drm/intel/issues/579
  [i915#602]: https://gitlab.freedesktop.org/drm/intel/issues/602
  [i915#72]: https://gitlab.freedesktop.org/drm/intel/issues/72
  [i915#92]: https://gitlab.freedesktop.org/drm/intel/issues/92
  [i915#95]: https://gitlab.freedesktop.org/drm/intel/issues/95
  [k.org#202321]: https://bugzilla.kernel.org/show_bug.cgi?id=202321


Participating hosts (10 -> 8)
------------------------------

  Missing    (2): pig-skl-6260u pig-glk-j5005 


Build changes
-------------

  * CI: CI-20190529 -> None
  * IGT: IGT_5880 -> IGTPW_5249
  * Piglit: piglit_4509 -> None

  CI-20190529: 20190529
  CI_DRM_9441: 6e992bb7585d1bee238776d8fe0512a70a22a1a0 @ git://anongit.freedesktop.org/gfx-ci/linux
  IGTPW_5249: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
  IGT_5880: d67bad61dc9a7515f94a7eecadd3bcd6b4f9d49e @ git://anongit.freedesktop.org/xorg/app/intel-gpu-tools
  piglit_4509: fdc5a4ca11124ab8413c7988896eec4c97336694 @ git://anongit.freedesktop.org/piglit

== Logs ==

For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html

[-- Attachment #1.2: Type: text/html, Size: 27760 bytes --]

[-- Attachment #2: Type: text/plain, Size: 154 bytes --]

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [igt-dev] ✗ Fi.CI.IGT: failure for runner: Don't kill a test on taint if watching timeouts
  2020-12-04 14:35 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork
@ 2020-12-04 15:44   ` Janusz Krzysztofik
  2020-12-04 15:53     ` [igt-dev] =?unknown-8bit?b?4pyX?= " Chris Wilson
  2020-12-04 17:28   ` [igt-dev] ✗ " Janusz Krzysztofik
  1 sibling, 1 reply; 10+ messages in thread
From: Janusz Krzysztofik @ 2020-12-04 15:44 UTC (permalink / raw)
  To: igt-dev; +Cc: Petri Latvala, Lakshminarayana Vudum


[-- Attachment #1.1: Type: text/plain, Size: 6797 bytes --]

On Fri, 2020-12-04 at 14:35 +0000, Patchwork wrote:
> 
> Patch Details
> 
> Series:runner: Don't kill a test on taint if watching timeouts
> URL:https://patchwork.freedesktop.org/series/84577/
> State:failure
> 
>     Details:https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
> 
> 
> 
> 
>     CI Bug Log - changes from CI_DRM_9441_full -> IGTPW_5249_full
> Summary
> FAILURE
> Serious unknown changes coming with IGTPW_5249_full absolutely need to be
> 
>   verified manually.
> If you think the reported changes have nothing to do with the changes
> 
>   introduced in IGTPW_5249_full, please notify your bug team to allow them
> 
>   to document this new failure mode, which will reduce false positives in CI.
> External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
> Possible new issues
> Here are the unknown changes that may have been introduced in IGTPW_5249_full:
> IGT changes
> Possible regressions
> 
> igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend:
> shard-iclb:         PASS -> DMESG-WARN
> 
> 
> 

I can't believe the change in igt_runner to not abort immediately on kernel taint could cause the driver to fail with a warning and trigger that taint.  There  must be some other reason.
> Warnings
> 
> 
> igt@gem_exec_reloc@basic-parallel:
> 
> 
> shard-kbl:          TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> shard-tglb:         TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> shard-apl:          TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> shard-iclb:         TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> shard-glk:          TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> 
> 
Hmm, I have no idea why output from this test is now less complete than before.  My expectation was we should get more, not less. 
Petri, do you think this may be related my implementation of  the change?
Thanks,Janusz
> Known issues
> Here are the changes found in IGTPW_5249_full that come from known issues:
> IGT changes
> Issues hit
> 
> 
> igt@i915_pm_backlight@fade_with_suspend:
> 
> 
> shard-tglb:         PASS -> DMESG-WARN (i915#1436 / i915#1602 / i915#1887 / i915#2411)
> 
> 
> shard-iclb:         PASS -> DMESG-WARN (i915#1602)
> 
> 
> 
> 
> igt@i915_pm_rpm@dpms-non-lpsp:
> 
> 
> shard-kbl:          PASS -> SKIP (fdo#109271)
> 
> 
> shard-apl:          PASS -> SKIP (fdo#109271)
> 
> 
> shard-glk:          PASS -> SKIP (fdo#109271)
> 
> 
> shard-hsw:          PASS -> SKIP (fdo#109271)
> 
> 
> 
> 
> igt@i915_suspend@forcewake:
> 
> shard-kbl:          PASS -> DMESG-WARN (i915#180)
> 
> 
> 
> igt@kms_async_flips@test-time-stamp:
> 
> shard-tglb:         PASS -> FAIL (i915#2597)
> 
> 
> 
> igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding:
> 
> 
> shard-kbl:          PASS -> FAIL (i915#54)
> 
> 
> shard-glk:          PASS -> FAIL (i915#54)
> 
> 
> shard-apl:          PASS -> FAIL (i915#54)
> 
> 
> 
> 
> igt@kms_draw_crc@fill-fb:
> 
> shard-snb:          PASS -> SKIP (fdo#109271) +2 similar issues
> 
> 
> 
> igt@kms_psr@psr2_cursor_plane_move:
> 
> shard-iclb:         PASS -> SKIP (fdo#109441) +2 similar issues
> 
> 
> 
> igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend:
> 
> 
> shard-hsw:          PASS -> DMESG-WARN (i915#2637)
> 
> 
> shard-kbl:          PASS -> INCOMPLETE (i915#155)
> 
> 
> shard-apl:          PASS -> DMESG-WARN (i915#2635)
> 
> 
> shard-glk:          PASS -> DMESG-WARN (i915#2635)
> 
> 
> shard-tglb:         PASS -> INCOMPLETE (i915#1436 / i915#1602 / i915#1798 / i915#1887 / i915#1982 / i915#2411 / i915#456)
> 
> 
> 
> 
> Possible fixes
> 
> 
> igt@gem_exec_gttfill@engines@rcs0:
> 
> shard-glk:          DMESG-WARN (i915#118 / i915#95) -> PASS +2 similar issues
> 
> 
> 
> igt@i915_pm_rpm@sysfs-read:
> 
> 
> shard-iclb:         SKIP (i915#579) -> PASS
> 
> 
> shard-tglb:         SKIP (i915#579) -> PASS
> 
> 
> 
> 
> igt@kms_color@pipe-a-ctm-max:
> 
> 
> shard-kbl:          FAIL (i915#1292) -> PASS
> 
> 
> shard-apl:          FAIL (i915#1292) -> PASS
> 
> 
> 
> 
> igt@kms_cursor_legacy@2x-long-flip-vs-cursor-legacy:
> 
> shard-glk:          FAIL (i915#72) -> PASS
> 
> 
> 
> igt@kms_cursor_legacy@cursor-vs-flip-toggle:
> 
> shard-hsw:          FAIL (i915#2370) -> PASS
> 
> 
> 
> igt@kms_fbcon_fbt@fbc-suspend:
> 
> shard-kbl:          INCOMPLETE (i915#155 / i915#180) -> PASS
> 
> 
> 
> igt@kms_psr@psr2_no_drrs:
> 
> shard-iclb:         SKIP (fdo#109441) -> PASS +1 similar issue
> 
> 
> 
> igt@perf_pmu@rc6-runtime-pm:
> 
> 
> shard-glk:          SKIP (fdo#109271) -> PASS +1 similar issue
> 
> 
> shard-apl:          SKIP (fdo#109271) -> PASS +1 similar issue
> 
> 
> shard-kbl:          SKIP (fdo#109271) -> PASS +1 similar issue
> 
> 
> shard-tglb:         SKIP (fdo#111719) -> PASS
> 
> 
> shard-hsw:          SKIP (fdo#109271) -> PASS +1 similar issue
> 
> 
> shard-iclb:         SKIP (i915#293) -> PASS
> 
> 
> 
> 
> Warnings
> 
> 
> igt@i915_pm_rc6_residency@rc6-fence:
> 
> shard-iclb:         WARN (i915#1804 / i915#2684) -> WARN (i915#2681 / i915#2684)
> 
> 
> 
> igt@i915_pm_rc6_residency@rc6-idle:
> 
> shard-iclb:         WARN (i915#2684) -> WARN (i915#2681 / i915#2684)
> 
> 
> 
> igt@i915_pm_rpm@dpms-non-lpsp:
> 
> 
> shard-tglb:         SKIP (fdo#111644 / i915#1397 / i915#2411) -> SKIP (i915#579)
> 
> 
> shard-iclb:         SKIP (fdo#110892) -> SKIP (i915#579)
> 
> 
> 
> 
> igt@i915_pm_rpm@modeset-pc8-residency-stress:
> 
> 
> shard-tglb:         SKIP (i915#579) -> SKIP (fdo#109506 / i915#2411)
> 
> 
> shard-iclb:         SKIP (i915#579) -> SKIP (fdo#109293 / fdo#109506)
> 
> 
> 
> 
> igt@runner@aborted:
> 
> 
> shard-kbl:          (FAIL, FAIL) (i915#2295 / i915#2722 / i915#483 / i915#92) -> (FAIL, FAIL, FAIL) (i915#1814 / i915#2295 / i915#2722 / i915#483 / i915#602)
> 
> 
> shard-iclb:         FAIL (i915#2295 / i915#2722 / i915#483) -> (FAIL, FAIL, FAIL) (i915#1814 / i915#2295 / i915#2722 / i915#483)
> 
> 
> shard-apl:          FAIL (i915#2295 / i915#2722) -> (FAIL, FAIL) (i915#1814 / i915#2295 / i915#2722)
> 
> 
> shard-glk:          FAIL (i915#2295 / i915#2722 / k.org#202321) -> (FAIL, FAIL) (i915#1814 / i915#2295 / i915#2722 / k.org#202321)
> 
> 
> shard-tglb:         FAIL (i915#2295 / i915#2722) -> (FAIL, FAIL, FAIL) (i915#1602 / i915#2295 / i915#2722)
> 
> 
> 
> 
> Participating hosts (10 -> 8)
> Missing    (2): pig-skl-6260u pig-glk-j5005 
> Build changes
> 
> CI: CI-20190529 -> None
> IGT: IGT_5880 -> IGTPW_5249
> Piglit: piglit_4509 -> None
> 
> CI-20190529: 20190529
> 
>   CI_DRM_9441: 6e992bb7585d1bee238776d8fe0512a70a22a1a0 @ git://anongit.freedesktop.org/gfx-ci/linux
> 
>   IGTPW_5249: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
> 
>   IGT_5880: d67bad61dc9a7515f94a7eecadd3bcd6b4f9d49e @ git://anongit.freedesktop.org/xorg/app/intel-gpu-tools
> 
>   piglit_4509: fdc5a4ca11124ab8413c7988896eec4c97336694 @ git://anongit.freedesktop.org/piglit
> 
> 
> 

[-- Attachment #1.2: Type: text/html, Size: 28756 bytes --]

[-- Attachment #2: Type: text/plain, Size: 154 bytes --]

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [igt-dev]  =?unknown-8bit?b?4pyX?= Fi.CI.IGT: failure for runner: Don't kill a test on taint if watching timeouts
  2020-12-04 15:44   ` Janusz Krzysztofik
@ 2020-12-04 15:53     ` Chris Wilson
  0 siblings, 0 replies; 10+ messages in thread
From: Chris Wilson @ 2020-12-04 15:53 UTC (permalink / raw)
  To: Janusz Krzysztofik, igt-dev; +Cc: Petri Latvala, Lakshminarayana Vudum

Quoting Janusz Krzysztofik (2020-12-04 15:44:01)
> On Fri, 2020-12-04 at 14:35 +0000, Patchwork wrote:
> 
>     Patch Details
> 
>     Series:  runner: Don't kill a test on taint if watching timeouts
>     URL:     https://patchwork.freedesktop.org/series/84577/
>     State:   failure
>     Details: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
> 
>     CI Bug Log - changes from CI_DRM_9441_full -> IGTPW_5249_full
> 
>     Summary
> 
>     FAILURE
> 
>     Serious unknown changes coming with IGTPW_5249_full absolutely need to be
>     verified manually.
> 
>     If you think the reported changes have nothing to do with the changes
>     introduced in IGTPW_5249_full, please notify your bug team to allow them
>     to document this new failure mode, which will reduce false positives in CI.
> 
>     External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/
>     index.html
> 
>     Possible new issues
> 
>     Here are the unknown changes that may have been introduced in
>     IGTPW_5249_full:
> 
>     IGT changes
> 
>     Possible regressions
> 
>       □ igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend:
>           ☆ shard-iclb: PASS -> DMESG-WARN
> 
> 
> I can't believe the change in igt_runner to not abort immediately on kernel
> taint 
> could cause the driver to fail with a warning and trigger that taint.  
> There must be some other reason.
> 
> 
>     Warnings
> 
>       □ igt@gem_exec_reloc@basic-parallel:
> 
>           ☆ shard-kbl: TIMEOUT (i915#1729) -> TIMEOUT
> 
>           ☆ shard-tglb: TIMEOUT (i915#1729) -> TIMEOUT
> 
>           ☆ shard-apl: TIMEOUT (i915#1729) -> TIMEOUT
> 
>           ☆ shard-iclb: TIMEOUT (i915#1729) -> TIMEOUT
> 
>           ☆ shard-glk: TIMEOUT (i915#1729) -> TIMEOUT
> 
> Hmm, I have no idea why output from this test is now less complete than before.
> My expectation was we should get more, not less.
> 
> Petri, do you think this may be related my implementation of the change?

       if (settings->per_test_timeout != 0 &&
-           time_since_subtest > settings->per_test_timeout)
-               return show_kernel_task_state("Per-test timeout exceeded. Killing the current test with SIGQUIT.\n");
+           time_since_subtest > settings->per_test_timeout / decrease) {
+               if (decrease > 1)
+                       return "Killing the test because the kernel is tainted.\n";
+               return "Per-test timeout exceeded. Killing the current test with SIGQUIT.\n";
+       }

        if (settings->inactivity_timeout != 0 &&
-           time_since_activity > settings->inactivity_timeout)
-               return show_kernel_task_state("Inactivity timeout exceeded. Killing the current test with SIGQUIT.\n");
+           time_since_activity > settings->inactivity_timeout / decrease ) {
+               if (decrease > 1)
+                       return "Killing the test because the kernel is tainted.\n";
+               return "Inactivity timeout exceeded. Killing the current test with SIGQUIT.\n";
+       }

The extra information was from show_kernel_task_state().
-Chris
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [igt-dev] ✗ Fi.CI.IGT: failure for runner: Don't kill a test on taint if watching timeouts
  2020-12-04 14:35 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork
  2020-12-04 15:44   ` Janusz Krzysztofik
@ 2020-12-04 17:28   ` Janusz Krzysztofik
  1 sibling, 0 replies; 10+ messages in thread
From: Janusz Krzysztofik @ 2020-12-04 17:28 UTC (permalink / raw)
  To: igt-dev; +Cc: Petri Latvala, Lakshminarayana Vudum


[-- Attachment #1.1: Type: text/plain, Size: 6797 bytes --]

On Fri, 2020-12-04 at 14:35 +0000, Patchwork wrote:
> 
> Patch Details
> 
> Series:runner: Don't kill a test on taint if watching timeouts
> URL:https://patchwork.freedesktop.org/series/84577/
> State:failure
> 
>     Details:https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
> 
> 
> 
> 
>     CI Bug Log - changes from CI_DRM_9441_full -> IGTPW_5249_full
> Summary
> FAILURE
> Serious unknown changes coming with IGTPW_5249_full absolutely need to be
> 
>   verified manually.
> If you think the reported changes have nothing to do with the changes
> 
>   introduced in IGTPW_5249_full, please notify your bug team to allow them
> 
>   to document this new failure mode, which will reduce false positives in CI.
> External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
> Possible new issues
> Here are the unknown changes that may have been introduced in IGTPW_5249_full:
> IGT changes
> Possible regressions
> 
> igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend:
> shard-iclb:         PASS -> DMESG-WARN
> 
> 
> 

I can't believe the change in igt_runner to not abort immediately on kernel taint could cause the driver to fail with a warning and trigger that taint.  There  must be some other reason.
> Warnings
> 
> 
> igt@gem_exec_reloc@basic-parallel:
> 
> 
> shard-kbl:          TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> shard-tglb:         TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> shard-apl:          TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> shard-iclb:         TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> shard-glk:          TIMEOUT (i915#1729) -> TIMEOUT
> 
> 
> 
> 
Hmm, I have no idea why output from this test is now less complete than before.  My expectation was we should get more, not less. 
Petri, do you think this may be related my implementation of  the change?
Thanks,Janusz
> Known issues
> Here are the changes found in IGTPW_5249_full that come from known issues:
> IGT changes
> Issues hit
> 
> 
> igt@i915_pm_backlight@fade_with_suspend:
> 
> 
> shard-tglb:         PASS -> DMESG-WARN (i915#1436 / i915#1602 / i915#1887 / i915#2411)
> 
> 
> shard-iclb:         PASS -> DMESG-WARN (i915#1602)
> 
> 
> 
> 
> igt@i915_pm_rpm@dpms-non-lpsp:
> 
> 
> shard-kbl:          PASS -> SKIP (fdo#109271)
> 
> 
> shard-apl:          PASS -> SKIP (fdo#109271)
> 
> 
> shard-glk:          PASS -> SKIP (fdo#109271)
> 
> 
> shard-hsw:          PASS -> SKIP (fdo#109271)
> 
> 
> 
> 
> igt@i915_suspend@forcewake:
> 
> shard-kbl:          PASS -> DMESG-WARN (i915#180)
> 
> 
> 
> igt@kms_async_flips@test-time-stamp:
> 
> shard-tglb:         PASS -> FAIL (i915#2597)
> 
> 
> 
> igt@kms_cursor_crc@pipe-c-cursor-256x85-sliding:
> 
> 
> shard-kbl:          PASS -> FAIL (i915#54)
> 
> 
> shard-glk:          PASS -> FAIL (i915#54)
> 
> 
> shard-apl:          PASS -> FAIL (i915#54)
> 
> 
> 
> 
> igt@kms_draw_crc@fill-fb:
> 
> shard-snb:          PASS -> SKIP (fdo#109271) +2 similar issues
> 
> 
> 
> igt@kms_psr@psr2_cursor_plane_move:
> 
> shard-iclb:         PASS -> SKIP (fdo#109441) +2 similar issues
> 
> 
> 
> igt@kms_vblank@pipe-b-ts-continuation-dpms-suspend:
> 
> 
> shard-hsw:          PASS -> DMESG-WARN (i915#2637)
> 
> 
> shard-kbl:          PASS -> INCOMPLETE (i915#155)
> 
> 
> shard-apl:          PASS -> DMESG-WARN (i915#2635)
> 
> 
> shard-glk:          PASS -> DMESG-WARN (i915#2635)
> 
> 
> shard-tglb:         PASS -> INCOMPLETE (i915#1436 / i915#1602 / i915#1798 / i915#1887 / i915#1982 / i915#2411 / i915#456)
> 
> 
> 
> 
> Possible fixes
> 
> 
> igt@gem_exec_gttfill@engines@rcs0:
> 
> shard-glk:          DMESG-WARN (i915#118 / i915#95) -> PASS +2 similar issues
> 
> 
> 
> igt@i915_pm_rpm@sysfs-read:
> 
> 
> shard-iclb:         SKIP (i915#579) -> PASS
> 
> 
> shard-tglb:         SKIP (i915#579) -> PASS
> 
> 
> 
> 
> igt@kms_color@pipe-a-ctm-max:
> 
> 
> shard-kbl:          FAIL (i915#1292) -> PASS
> 
> 
> shard-apl:          FAIL (i915#1292) -> PASS
> 
> 
> 
> 
> igt@kms_cursor_legacy@2x-long-flip-vs-cursor-legacy:
> 
> shard-glk:          FAIL (i915#72) -> PASS
> 
> 
> 
> igt@kms_cursor_legacy@cursor-vs-flip-toggle:
> 
> shard-hsw:          FAIL (i915#2370) -> PASS
> 
> 
> 
> igt@kms_fbcon_fbt@fbc-suspend:
> 
> shard-kbl:          INCOMPLETE (i915#155 / i915#180) -> PASS
> 
> 
> 
> igt@kms_psr@psr2_no_drrs:
> 
> shard-iclb:         SKIP (fdo#109441) -> PASS +1 similar issue
> 
> 
> 
> igt@perf_pmu@rc6-runtime-pm:
> 
> 
> shard-glk:          SKIP (fdo#109271) -> PASS +1 similar issue
> 
> 
> shard-apl:          SKIP (fdo#109271) -> PASS +1 similar issue
> 
> 
> shard-kbl:          SKIP (fdo#109271) -> PASS +1 similar issue
> 
> 
> shard-tglb:         SKIP (fdo#111719) -> PASS
> 
> 
> shard-hsw:          SKIP (fdo#109271) -> PASS +1 similar issue
> 
> 
> shard-iclb:         SKIP (i915#293) -> PASS
> 
> 
> 
> 
> Warnings
> 
> 
> igt@i915_pm_rc6_residency@rc6-fence:
> 
> shard-iclb:         WARN (i915#1804 / i915#2684) -> WARN (i915#2681 / i915#2684)
> 
> 
> 
> igt@i915_pm_rc6_residency@rc6-idle:
> 
> shard-iclb:         WARN (i915#2684) -> WARN (i915#2681 / i915#2684)
> 
> 
> 
> igt@i915_pm_rpm@dpms-non-lpsp:
> 
> 
> shard-tglb:         SKIP (fdo#111644 / i915#1397 / i915#2411) -> SKIP (i915#579)
> 
> 
> shard-iclb:         SKIP (fdo#110892) -> SKIP (i915#579)
> 
> 
> 
> 
> igt@i915_pm_rpm@modeset-pc8-residency-stress:
> 
> 
> shard-tglb:         SKIP (i915#579) -> SKIP (fdo#109506 / i915#2411)
> 
> 
> shard-iclb:         SKIP (i915#579) -> SKIP (fdo#109293 / fdo#109506)
> 
> 
> 
> 
> igt@runner@aborted:
> 
> 
> shard-kbl:          (FAIL, FAIL) (i915#2295 / i915#2722 / i915#483 / i915#92) -> (FAIL, FAIL, FAIL) (i915#1814 / i915#2295 / i915#2722 / i915#483 / i915#602)
> 
> 
> shard-iclb:         FAIL (i915#2295 / i915#2722 / i915#483) -> (FAIL, FAIL, FAIL) (i915#1814 / i915#2295 / i915#2722 / i915#483)
> 
> 
> shard-apl:          FAIL (i915#2295 / i915#2722) -> (FAIL, FAIL) (i915#1814 / i915#2295 / i915#2722)
> 
> 
> shard-glk:          FAIL (i915#2295 / i915#2722 / k.org#202321) -> (FAIL, FAIL) (i915#1814 / i915#2295 / i915#2722 / k.org#202321)
> 
> 
> shard-tglb:         FAIL (i915#2295 / i915#2722) -> (FAIL, FAIL, FAIL) (i915#1602 / i915#2295 / i915#2722)
> 
> 
> 
> 
> Participating hosts (10 -> 8)
> Missing    (2): pig-skl-6260u pig-glk-j5005 
> Build changes
> 
> CI: CI-20190529 -> None
> IGT: IGT_5880 -> IGTPW_5249
> Piglit: piglit_4509 -> None
> 
> CI-20190529: 20190529
> 
>   CI_DRM_9441: 6e992bb7585d1bee238776d8fe0512a70a22a1a0 @ git://anongit.freedesktop.org/gfx-ci/linux
> 
>   IGTPW_5249: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_5249/index.html
> 
>   IGT_5880: d67bad61dc9a7515f94a7eecadd3bcd6b4f9d49e @ git://anongit.freedesktop.org/xorg/app/intel-gpu-tools
> 
>   piglit_4509: fdc5a4ca11124ab8413c7988896eec4c97336694 @ git://anongit.freedesktop.org/piglit
> 
> 
> 

[-- Attachment #1.2: Type: text/html, Size: 28838 bytes --]

[-- Attachment #2: Type: text/plain, Size: 154 bytes --]

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 10+ messages in thread

end of thread, other threads:[~2020-12-04 17:28 UTC | newest]

Thread overview: 10+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2020-12-04 11:51 [igt-dev] [PATCH i-g-t] runner: Don't kill a test on taint if watching timeouts Janusz Krzysztofik
2020-12-04 11:57 ` [Intel-gfx] " Janusz Krzysztofik
2020-12-04 12:06 ` [igt-dev] " Chris Wilson
2020-12-04 12:20   ` [Intel-gfx] " Janusz Krzysztofik
2020-12-04 12:20     ` Janusz Krzysztofik
2020-12-04 12:39 ` [igt-dev] ✓ Fi.CI.BAT: success for " Patchwork
2020-12-04 14:35 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork
2020-12-04 15:44   ` Janusz Krzysztofik
2020-12-04 15:53     ` [igt-dev] =?unknown-8bit?b?4pyX?= " Chris Wilson
2020-12-04 17:28   ` [igt-dev] ✗ " Janusz Krzysztofik

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.